#!/usr/bin/env python
# coding: utf-8
"""
Multi-line documentation placeholder if whole module needs to be explained.

Multi line documentation for data processing. Multi line documentation
for data processing. Multi line documentation for data processing.
Multi line documentation for data processing. Multi line documentation
for data processing. Multi line documentation for data processing.
Multi line documentation for data processing.
"""
import xarray as xr


def main(dataarray):
    """One line documentation for data processing.

    Multi line documentation for data processing. Multi line documentation
    for data processing. Multi line documentation for data processing. Multi
    line documentation for data processing. Multi line documentation for
    data processing. Multi line documentation for data processing. Multi
    line documentation for data processing. Multi line documentation for
    data processing.

    Arguments
    =========
    dataarray: <Description>
    argument1: <Description>
    ...
    argumentX: <Description>

    Returns
    =======
    dataarray: <Description>
    """
    assert isinstance(dataarray, xr.DataArray), "Input is not an xr.DataArray"

    # add data processing code here

    return dataarray
